@@ -38,6 +38,11 @@ enum obs_source_type {
 	OBS_SOURCE_TYPE_SCENE,
 };
 
+enum obs_balance_type {
+	OBS_BALANCE_TYPE_SINE_LAW,
+	OBS_BALANCE_TYPE_SQUARE_LAW,
+	OBS_BALANCE_TYPE_LINEAR,
+};
 
 /**
  * @name Source output flags
