@@ -17,9 +17,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
-#include <inttypes.h>
-#include "amf-encoder-h265.h"
-#include "utility.h"
+#include "amf-encoder-h265.hpp"
+#include <cinttypes>
+#include "utility.hpp"
 
 #define PREFIX "[H265]<Id: %lld> "
 
@@ -27,7 +27,7 @@ using namespace Plugin;
 using namespace Plugin::AMD;
 using namespace Utility;
 
-Plugin::AMD::EncoderH265::EncoderH265(std::shared_ptr<API::IAPI> videoAPI, API::Adapter videoAdapter,
+Plugin::AMD::EncoderH265::EncoderH265(std::shared_ptr<API::IAPI> videoAPI, const API::Adapter& videoAdapter,
 									  bool useOpenCLSubmission, bool useOpenCLConversion, ColorFormat colorFormat,
 									  ColorSpace colorSpace, bool fullRangeColor, bool useAsyncQueue,
 									  size_t asyncQueueSize)
@@ -324,16 +324,7 @@ std::vector<ProfileLevel> Plugin::AMD::EncoderH265::CapsProfileLevel()
 void Plugin::AMD::EncoderH265::SetProfileLevel(ProfileLevel v)
 {
 	AMFTRACECALL;
-
-	if (v == ProfileLevel::Automatic)
-		v = Utility::H265ProfileLevel(m_Resolution, m_FrameRate);
-
-	AMF_RESULT res = m_AMFEncoder->SetProperty(AMF_VIDEO_ENCODER_HEVC_PROFILE_LEVEL, ((int64_t)v) * 3);
-	if (res != AMF_OK) {
-		QUICK_FORMAT_MESSAGE(errMsg, "<Id: %lld> <" __FUNCTION_NAME__ "> Failed to set to %lld, error %ls (code %d)",
-							 m_UniqueId, (int64_t)v, m_AMF->GetTrace()->GetResultText(res), res);
-		throw std::exception(errMsg.c_str());
-	}
+	SetProfileLevel(v, m_Resolution, m_FrameRate);
 }
 
 void Plugin::AMD::EncoderH265::SetProfileLevel(ProfileLevel v, std::pair<uint32_t, uint32_t> r,
@@ -344,6 +335,19 @@ void Plugin::AMD::EncoderH265::SetProfileLevel(ProfileLevel v, std::pair<uint32_
 	if (v == ProfileLevel::Automatic)
 		v = Utility::H265ProfileLevel(r, h);
 
+	bool         supported       = false;
+	ProfileLevel supported_level = v;
+	for (auto k : CapsProfileLevel()) {
+		if (k == supported_level) {
+			supported = true;
+			break;
+		}
+		if (k > v && !supported) {
+			v = k;
+			break;
+		}
+	}
+
 	AMF_RESULT res = m_AMFEncoder->SetProperty(AMF_VIDEO_ENCODER_HEVC_PROFILE_LEVEL, ((int64_t)v) * 3);
 	if (res != AMF_OK) {
 		QUICK_FORMAT_MESSAGE(errMsg, "<Id: %lld> <" __FUNCTION_NAME__ "> Failed to set to %lld, error %ls (code %d)",
