@@ -17,11 +17,11 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
-#include "amf-capabilities.h"
-#include "amf-encoder-h264.h"
-#include "enc-h264.h"
-#include "strings.h"
-#include "utility.h"
+#include "enc-h264.hpp"
+#include "amf-capabilities.hpp"
+#include "amf-encoder-h264.hpp"
+#include "strings.hpp"
+#include "utility.hpp"
 
 #define PREFIX "[H264/AVC]"
 
@@ -1313,17 +1313,18 @@ Plugin::Interface::H264Interface::H264Interface(obs_data_t* data, obs_encoder_t*
 		(size_t)obs_data_get_int(data, P_QUEUESIZE));
 
 	/// Static Properties
+	m_VideoEncoder->SetUsage(Plugin::AMD::Usage::Transcoding);
 	m_VideoEncoder->SetQualityPreset(static_cast<QualityPreset>(obs_data_get_int(data, P_QUALITYPRESET)));
 
+	/// Frame
+	m_VideoEncoder->SetResolution(std::make_pair(obsWidth, obsHeight));
+	m_VideoEncoder->SetFrameRate(std::make_pair(obsFPSnum, obsFPSden));
+
 	/// Profile & Level
 	m_VideoEncoder->SetProfile(static_cast<Profile>(obs_data_get_int(data, P_PROFILE)));
 	m_VideoEncoder->SetProfileLevel(static_cast<ProfileLevel>(obs_data_get_int(data, P_PROFILELEVEL)),
 									std::make_pair(obsWidth, obsHeight), std::make_pair(obsFPSnum, obsFPSden));
 
-	/// Frame
-	m_VideoEncoder->SetResolution(std::make_pair(obsWidth, obsHeight));
-	m_VideoEncoder->SetFrameRate(std::make_pair(obsFPSnum, obsFPSden));
-
 	try {
 		m_VideoEncoder->SetCodingType(static_cast<CodingType>(obs_data_get_int(data, P_CODINGTYPE)));
 	} catch (...) {
