@@ -17,12 +17,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
-#include "amf-capabilities.h"
-#include "amf-encoder-h265.h"
-#include "amf-encoder.h"
-#include "enc-h265.h"
-#include "strings.h"
-#include "utility.h"
+#include "enc-h265.hpp"
+#include "amf-capabilities.hpp"
+#include "amf-encoder-h265.hpp"
+#include "amf-encoder.hpp"
+#include "strings.hpp"
+#include "utility.hpp"
 
 #define PREFIX "[H265/HEVC]"
 
@@ -892,18 +892,19 @@ Plugin::Interface::H265Interface::H265Interface(obs_data_t* data, obs_encoder_t*
 		(size_t)obs_data_get_int(data, P_QUEUESIZE));
 
 	/// Static Properties
-	//m_VideoEncoder->SetUsage(Usage::Transcoding);
+	m_VideoEncoder->SetUsage(Plugin::AMD::Usage::Transcoding);
 	m_VideoEncoder->SetQualityPreset(static_cast<QualityPreset>(obs_data_get_int(data, P_QUALITYPRESET)));
 
+	/// Frame
+	m_VideoEncoder->SetResolution(std::make_pair(obsWidth, obsHeight));
+	m_VideoEncoder->SetFrameRate(std::make_pair(obsFPSnum, obsFPSden));
+
 	/// Profile & Level
 	m_VideoEncoder->SetProfile(static_cast<Profile>(obs_data_get_int(data, P_PROFILE)));
 	m_VideoEncoder->SetProfileLevel(static_cast<ProfileLevel>(obs_data_get_int(data, P_PROFILELEVEL)),
 									std::make_pair(obsWidth, obsHeight), std::make_pair(obsFPSnum, obsFPSden));
 	m_VideoEncoder->SetTier(static_cast<H265::Tier>(obs_data_get_int(data, P_TIER)));
 
-	/// Frame
-	m_VideoEncoder->SetResolution(std::make_pair(obsWidth, obsHeight));
-	m_VideoEncoder->SetFrameRate(std::make_pair(obsFPSnum, obsFPSden));
 	///- Aspect Ratio
 
 	try {
