@@ -19,16 +19,17 @@
 
 #pragma once
 
+#include "utility.hpp"
 #include <map>
 #include <sstream>
-#include "amf-encoder-h264.h"
-#include "amf-encoder-h265.h"
-#include "amf-encoder.h"
-#include "amf.h"
-#include "components/VideoConverter.h"
-#include "components/VideoEncoderHEVC.h"
-#include "components/VideoEncoderVCE.h"
-#include "utility.h"
+#include "amf-encoder-h264.hpp"
+#include "amf-encoder-h265.hpp"
+#include "amf-encoder.hpp"
+#include "amf.hpp"
+
+#include <components/VideoConverter.h>
+#include <components/VideoEncoderHEVC.h>
+#include <components/VideoEncoderVCE.h>
 
 using namespace Plugin::AMD;
 
